Module error

Module error 

Enums

ErrorData
Errors related to alien-bindings operations.

Functions

binding_env_var
Derives the exact ALIEN_<NAME>_BINDING environment variable name that would have configured a binding with the given name — the same derivation alien-core uses to generate binding env vars, so this is guaranteed to match parse_bindings_from_env’s reverse parsing (see provider.rs).
map_cloud_client_error
Maps an alien_client_core::Error to an appropriate alien_bindings::Error.

Type Aliases

Error
Convenience alias representing a constructed AlienError with our ErrorData payload.
Result
Convenient alias with default error type ErrorData.