binding_env_var

Function binding_env_var 

pub fn binding_env_var(binding_name: &str) -> String
Derives the exact ALIEN_<NAME>_BINDING environment variable name that would have configured a binding with the given name — the same derivation alien-core uses to generate binding env vars, so this is guaranteed to match parse_bindings_from_env’s reverse parsing (see provider.rs).