Module presigned

Module presigned 

Structs

PresignedRequest
A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
PresignedResponse
Response from executing a presigned request

Enums

LocalOperation
Local filesystem operations
PresignedOperation
The type of operation a presigned request performs
PresignedRequestBackend
Storage backend representation for different presigned request types

Constants

PRESIGNED_RESPONSE_TOO_LARGE_MESSAGE
Stable message used when a bounded presigned GET exceeds its caller’s explicit limit. This uses the existing generic error variant so adding the bounded API does not add a variant to the exhaustively matchable public ErrorData enum.

Functions

redact_url_for_error
Remove credentials from a URL before storing it in an error or log record.