Module provider

Module provider 

Unified BindingsProvider implementation that supports multiple cloud providers

Structs

BindingsProvider
Direct platform-specific bindings provider. Routes to appropriate platform implementations based on binding configuration.
LazyEnvBindingsProvider
Environment-backed provider that defers cloud client configuration until the first binding is actually used.