pub struct AcaBuild { /* private fields */ }Expand description
Azure implementation of the Build trait using Container Apps Jobs.
Implementations
Sourceimpl AcaBuild
impl AcaBuild
Sourcepub async fn new(
binding_name: String,
binding: BuildBinding,
azure_config: &AzureClientConfig,
) -> Result<Self, Error>
pub async fn new( binding_name: String, binding: BuildBinding, azure_config: &AzureClientConfig, ) -> Result<Self, Error>
Creates a new Azure Build instance from binding parameters.