pub struct LocalBuild { /* private fields */ }Expand description
Local implementation of the Build trait that runs bash scripts directly.
This implementation is stateless - all build state is encoded in the build ID
and stored in the filesystem.
Implementations
Sourceimpl LocalBuild
impl LocalBuild
Sourcepub fn new(binding_name: String, binding: BuildBinding) -> Result<Self>
pub fn new(binding_name: String, binding: BuildBinding) -> Result<Self>
Creates a new Local Build instance from binding parameters.
Sourcepub fn new_from_path(binding_name: String, base_dir: PathBuf) -> Self
pub fn new_from_path(binding_name: String, base_dir: PathBuf) -> Self
Creates a new Local Build instance from a directory path.