pub struct WaitUntilContext { /* private fields */ }Expand description
A context for managing wait_until tasks within an application. This handles local task execution and coordinates with the runtime via gRPC.
Implementations
Sourceimpl WaitUntilContext
impl WaitUntilContext
Sourcepub async fn from_env(application_id: Option<String>) -> Result<Self>
pub async fn from_env(application_id: Option<String>) -> Result<Self>
Creates a new WaitUntilContext and connects to gRPC endpoint from environment variables. This is the recommended way to create a WaitUntilContext in production.
Sourcepub async fn from_env_with_vars(
application_id: Option<String>,
env_vars: &HashMap<String, String>,
) -> Result<Self>
pub async fn from_env_with_vars( application_id: Option<String>, env_vars: &HashMap<String, String>, ) -> Result<Self>
Creates a new WaitUntilContext and connects to gRPC endpoint from provided environment variables.
Sourcepub fn new_with_grpc_client(
application_id: Option<String>,
grpc_client: WaitUntilServiceClient<Channel>,
) -> Self
pub fn new_with_grpc_client( application_id: Option<String>, grpc_client: WaitUntilServiceClient<Channel>, ) -> Self
Creates a new WaitUntilContext with a gRPC client.
Sourcepub fn set_grpc_client(&mut self, client: WaitUntilServiceClient<Channel>)
pub fn set_grpc_client(&mut self, client: WaitUntilServiceClient<Channel>)
Sets the gRPC client for communicating with the runtime.
Sourcepub fn application_id(&self) -> &str
pub fn application_id(&self) -> &str
Gets the application ID.
Sourcepub async fn start_drain_listener(&self) -> Result<()>
pub async fn start_drain_listener(&self) -> Result<()>
Starts a background task that waits for drain signals from the runtime. This should be called once when the application starts.