pub enum PutCondition {
None,
Absent,
Version(String),
}Expand description
A precondition for a KV put operation.
Variants
None
Replace any current value, or create the key when it is absent.
Absent
Create the key only when it is absent or logically expired.
Version(String)
Replace the value only when the key still has this opaque version.