pub struct ControlGrpcServer { /* private fields */ }Expand description
Control gRPC server implementation
Implementations
Sourceimpl ControlGrpcServer
impl ControlGrpcServer
pub fn new() -> Self
Sourcepub async fn get_http_port(&self) -> Option<u16>
pub async fn get_http_port(&self) -> Option<u16>
Get the registered HTTP port (if any)
Sourcepub async fn has_handler(&self, handler_type: &str, resource_name: &str) -> bool
pub async fn has_handler(&self, handler_type: &str, resource_name: &str) -> bool
Check if a handler is registered
Sourcepub async fn get_handlers(&self) -> Vec<HandlerRegistration>
pub async fn get_handlers(&self) -> Vec<HandlerRegistration>
Get all registered handlers
Sourcepub async fn wait_for_http_server(&self) -> Option<u16>
pub async fn wait_for_http_server(&self) -> Option<u16>
Wait for HTTP server to be registered
Sourcepub async fn send_task(
&self,
task: Task,
timeout: Duration,
) -> Result<TaskResult, String>
pub async fn send_task( &self, task: Task, timeout: Duration, ) -> Result<TaskResult, String>
Send a task to the application and wait for the result. This is used for all task types - the runtime must wait for the app to process before acknowledging to the platform (storage/cron/queue) or submitting responses (commands).
Sourcepub fn into_service(self) -> ControlServiceServer<Self>
pub fn into_service(self) -> ControlServiceServer<Self>
Convert to tonic service