Module presigned
alien_
bindings
3.3.26
Module presigned
Module Items
Structs
Enums
Constants
Functions
In crate alien_
bindings
alien_bindings
Module
presigned
Structs

Presigned
Request
A presigned request that can be serialized, stored, and executed later. Hides implementation details for different storage backends.
Presigned
Response
Response from executing a presigned request
Enums

Local
Operation
Local filesystem operations
Presigned
Operation
The type of operation a presigned request performs
Presigned
Request
Backend
Storage backend representation for different presigned request types
Constants

PRESIGNED_
RESPONSE_
TOO_
LARGE_
MESSAGE
Stable message used when a bounded presigned GET exceeds its caller’s explicit limit. This uses the existing generic error variant so adding the bounded API does not add a variant to the exhaustively matchable public
ErrorData
enum.
Functions

redact_
url_
for_
error
Remove credentials from a URL before storing it in an error or log record.