Storage

Trait Storage 

pub trait Storage: Binding + ObjectStore {
    // Required methods
    fn get_base_dir(&self) -> Path;
    fn get_url(&self) -> Url;
    fn presigned_put<'life0, 'life1, 'async_trait>(
        &'life0 self,
        path: &'life1 Path,
        expires_in: Duration,
    ) -> Pin<Box<dyn Future<Output = Result<PresignedRequest>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn presigned_get<'life0, 'life1, 'async_trait>(
        &'life0 self,
        path: &'life1 Path,
        expires_in: Duration,
    ) -> Pin<Box<dyn Future<Output = Result<PresignedRequest>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn presigned_delete<'life0, 'life1, 'async_trait>(
        &'life0 self,
        path: &'life1 Path,
        expires_in: Duration,
    ) -> Pin<Box<dyn Future<Output = Result<PresignedRequest>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
A storage binding that provides object store capabilities.

Required Methods

fn get_base_dir(&self) -> Path

Gets the base directory path configured for this storage binding.

fn get_url(&self) -> Url

Gets the underlying URL configured for this storage binding.

fn presigned_put<'life0, 'life1, 'async_trait>( &'life0 self, path: &'life1 Path, expires_in: Duration, ) -> Pin<Box<dyn Future<Output = Result<PresignedRequest>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Creates a presigned request for uploading data to the specified path. The request can be serialized, stored, and executed later.

fn presigned_get<'life0, 'life1, 'async_trait>( &'life0 self, path: &'life1 Path, expires_in: Duration, ) -> Pin<Box<dyn Future<Output = Result<PresignedRequest>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Creates a presigned request for downloading data from the specified path. The request can be serialized, stored, and executed later.

fn presigned_delete<'life0, 'life1, 'async_trait>( &'life0 self, path: &'life1 Path, expires_in: Duration, ) -> Pin<Box<dyn Future<Output = Result<PresignedRequest>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Creates a presigned request for deleting the object at the specified path. The request can be serialized, stored, and executed later.

Implementors